@@ -6,6 +6,7 @@ import locale
 import os
 import re
 import sys
+import logging
 
 # external modules
 import evdev
@@ -13,15 +14,25 @@ import evdev
 # internal modules
 from termkeymonitor.version import __version__
 
+logger = logging.getLogger(__name__)
+
 
 def find_keyboard_device():
-    return sorted(
+    keyboards = sorted(
         evdev.list_devices(),
         key=lambda p: (
             ("keyboard" not in evdev.InputDevice(p).name),
             len(evdev.InputDevice(p).name),
         ),
-    )[0]
+    )
+    if not keyboards:
+        raise argparse.ArgumentTypeError(
+            "No keyboards found. "
+            "Specify keyboard device via --device. "
+            "(try running 'python3 -m evdev.evtest') "
+            "Also: Do you have permissions for e.g. /dev/input/...?"
+        )
+    return keyboards[0]
 
 
 def stop_on_keyboardinterrupt(decorated_fun):
